==> beagle-0.0.12.tar.bz2: beagle-0.0.12/Tiles/TileBlog.cs <==
//
// TileBlog.cs
//
// Copyright (C) 2004 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Diagnostics;
using System.IO;

using BU = Beagle.Util;

namespace Beagle.Tile {

	[HitFlavor (Name="Feeds", Rank=800, Emblem="emblem-blog.png", Color="#f5f5fe",
		    Type="FeedItem")]
	public class TileBlog : TileFromHitTemplate 
	{
		public TileBlog (Hit _hit) : base (_hit, "template-blog.html")
		{
		}

		protected override void PopulateTemplate ()
		{
			base.PopulateTemplate ();

			string path = Hit ["fixme:cachedimg"];

			if (path != null && File.Exists (path))
				Template ["Icon"] = Images.GetHtmlSource (path, null);
			else
				Template ["Icon"] = Images.GetHtmlSource ("icon-blog", "text/html");

			if (Hit ["fixme:author"] != null && Hit ["fixme:author"] != "")
			    Template ["Author"] = Hit ["fixme:author"];
		}

		[TileAction]
		public override void Open ()
                {
			try {
				Gnome.Url.Show (Hit ["fixme:itemuri"]);
			} catch (Exception e) {
				Console.WriteLine ("Could not load handler for {0}: {1}", Hit ["fixme:itemuri"], e);
			}
		}
	}
}

==> beagle-0.1.4.tar.bz2: beagle-0.1.4/Tiles/TileBlog.cs <==
//
// TileBlog.cs
//
// Copyright (C) 2004 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Diagnostics;
using System.IO;

using BU = Beagle.Util;

namespace Beagle.Tile {

	[HitFlavor (Name="Feeds", Rank=800, Emblem="emblem-blog.png", Color="#f5f5fe",
		    Type="FeedItem")]
	public class TileBlog : TileFromHitTemplate 
	{
		public TileBlog (Hit _hit) : base (_hit, "template-blog.html")
		{
		}

		protected override void PopulateTemplate ()
		{
			base.PopulateTemplate ();

			string path = Hit ["fixme:cachedimg"];

			if (path != null && File.Exists (path))
				Template ["Icon"] = Images.GetHtmlSource (path, null);
			else
				Template ["Icon"] = Images.GetHtmlSource ("icon-blog", "text/html");

			if (Hit ["fixme:author"] != null && Hit ["fixme:author"] != "")
			    Template ["Author"] = Hit ["fixme:author"];
		}

		[TileAction]
		public override void Open ()
                {
#if ENABLE_DESKTOP_LAUNCH
			Process p = new Process ();
			p.StartInfo.UseShellExecute = false;
			p.StartInfo.FileName = "desktop-launch";
			p.StartInfo.Arguments = Hit ["dc:identifier"];

			try {
				p.Start ();
			} catch (Exception e) {
				Console.WriteLine ("Could not load handler for {0}: {1}", Hit ["fixme:itemuri"], e);
			}
#else			
			try {
				Gnome.Url.Show (Hit ["dc:identifier"]);
			} catch (Exception e) {
				Console.WriteLine ("Could not load handler for {0}: {1}", Hit ["fixme:itemuri"], e);
			}
#endif
		}
	}
}
